@@ -109,8 +109,9 @@ mod dynamic;
 mod reflect;
 
 pub use self::descriptor::{
-    DescriptorError, EnumDescriptor, EnumValueDescriptor, ExtensionDescriptor, FieldDescriptor,
-    FileDescriptor, Kind, MessageDescriptor, MethodDescriptor, OneofDescriptor, ServiceDescriptor,
+    Cardinality, DescriptorError, EnumDescriptor, EnumValueDescriptor, ExtensionDescriptor,
+    FieldDescriptor, FileDescriptor, Kind, MessageDescriptor, MethodDescriptor, OneofDescriptor,
+    ServiceDescriptor,
 };
 pub use self::dynamic::{DynamicMessage, MapKey, Value};
 pub use self::reflect::ReflectMessage;
